from setuptools import setup

setup(name='ihs_probability',
      version='0.1',
      description='Gaussian and Binomial distributions',
      packages=['ihs_probability'],
      author='Honoré Mbaya',
      author_email='honormbaya@gmail.com',
      zip_safe=False)
